Module: GitHubWebHooksReceiver

Defined in:
lib/github-web-hooks-receiver/base.rb,
lib/github-web-hooks-receiver.rb,
lib/github-web-hooks-receiver/app.rb,
lib/github-web-hooks-receiver/payload.rb,
lib/github-web-hooks-receiver/version.rb,
lib/github-web-hooks-receiver/repository.rb,
lib/github-web-hooks-receiver/path-resolver.rb

Overview

Copyright © 2010-2013 Kouhei Sutou <[email protected]> Copyright © 2015 Kenji Okimoto <[email protected]>

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see <www.gnu.org/licenses/>.

Defined Under Namespace

Modules: PathResolver Classes: App, Base, Payload, Repository

Constant Summary collapse

VERSION =
"1.0.0"